@@ -1,15 +1,16 @@
 import re
 import time
+from calendar import monthrange
 from dataclasses import dataclass
 from datetime import datetime, timezone, timedelta
 from typing import List, Union
 
 _PERIOD = r'^([+-]?\d+(?:\.\d+)?)?~([+-]?\d+(?:\.\d+)?)?$'
 
-_DIGIT_TIMESTAMP = r'^([+-])?(\d{4})(\d\d)(\d\d)(?:(\d\d)(?:(\d\d)(?:(\d\d)(\d+)?)?)?)?(?:\.(\d+))?$'
+_DIGIT_TIMESTAMP = r'^([+-])?(\d{4})(?(\d\d)(?:(\d\d)(?:(\d\d)(?:(\d\d)(?:(\d\d)(\d+)?)?)?)?)?)?(?:\.(\d+))?$'
 
-now = time.time()
-TIMEZONE_OFFSET_HOUR = (datetime.fromtimestamp(now) - datetime.utcfromtimestamp(now)).total_seconds() / 3600
+_now = time.time()
+TIMEZONE_OFFSET_HOUR = (datetime.fromtimestamp(_now) - datetime.utcfromtimestamp(_now)).total_seconds() / 3600
 
 
 class Period:
@@ -26,18 +27,34 @@ class Period:
         return self._duration_time
 
     def __init__(
-        self,
-        expression: str = None,
-        matched: re.Match = None,
-        begin: Union[str, datetime] = None,
-        end: Union[str, datetime] = None,
-        use_default_timezone=None
+            self,
+            expression: str = None,
+            matched: re.Match = None,
+            begin: Union[str, datetime] = None,
+            end: Union[str, datetime] = None,
+            use_default_timezone=None
     ):
         if not (expression or matched or begin or end):
             raise ValueError('`begin`, `end` or `period_string` is required.')
 
         if matched is None:
-            matched = is_period_string(expression)
+            # now = datetime.now()
+            # if expression == 'today':
+            #     self.begin = now.replace(hour=0, minute=0, second=0, microsecond=0)
+            #     self.end = now.replace(hour=23, minute=59, second=59, microsecond=999999)
+            #     return
+            #
+            # elif expression == 'week':
+            #     self.begin = now - timedelta(-7)
+            #     self.end = now.replace(hour=23, minute=59, second=59, microsecond=999999)
+            #     return
+            #
+            # elif expression == 'month':
+            #     self.begin = now.replace(day=1)
+            #     self.end = now.replace(day=monthrange(now.year, now.month))
+            #     return
+
+            matched = is_period_exp(expression)
 
             if matched is None:
                 raise ValueError('Invalid Period String:' + expression)
@@ -69,18 +86,13 @@ class Period:
 
 @dataclass
 class DateParts:
-    y: str
-    m: str
-    d: str
-    h: str
-    i: str
-
     def __init__(self, time: datetime):
         self.y = str(time.year).rjust(2, '0')
         self.m = str(time.month).rjust(2, '0')
         self.d = str(time.day).rjust(2, '0')
         self.h = str(time.hour).rjust(2, '0')
         self.i = str(time.minute).rjust(2, '0')
+        self.s = str(time.second).rjust(2, '0')
 
 
 def is_digit_timestamp(timestamp_string: str) -> re.Match:
@@ -96,15 +108,17 @@ def _get_part(value: int, default: int):
 
 
 def from_digit_timestamp(
-    timestamp_string: str,
-    matched: re.Match = -1,
-    use_default_timezone=False,
-    to_end=False
+        timestamp_string: str,
+        matched: re.Match = -1,
+        use_default_timezone=False,
+        to_end=False
 ) -> datetime:
     """ Get Datetime from Digit Timestamp String
 
     UTC:
 
+    - 1234
+    - 123412
     - 12341212
     - 1234121213
     - 123412121212
@@ -136,11 +150,12 @@ def from_digit_timestamp(
         timezone_hours = int(z) if flag != '-' else -int(z)
     elif use_default_timezone:
         timezone_hours = TIMEZONE_OFFSET_HOUR
-
+    y = int(y)
+    m = int(_get_part(m, 12 if to_end else 1))
     return datetime(
-        int(y),
-        int(m),
-        int(d),
+        y,
+        m,
+        int(_get_part(d, monthrange(y, m)[1] if to_end else 1)),
         int(_get_part(h, 23 if to_end else 0)),
         int(_get_part(i, 59 if to_end else 0)),
         int(_get_part(s, 59 if to_end else 0)),
@@ -153,9 +168,10 @@ def from_digit_timestamp(
     )
 
 
-def is_period_string(period_string: str) -> Union[re.Match, None]:
+def is_period_exp(period_string: str) -> Union[re.Match, None]:
     """ Check the String be Period-able String
     """
+
     if period_string != '~':
         return re.fullmatch(_PERIOD, period_string)
 
