@@ -1,11 +1,10 @@
 from dataclasses import dataclass
 from datetime import datetime
 from math import ceil
-from typing import Type, Union, List, Tuple, Dict, TypedDict, Optional
+from typing import Type, Union, List, Tuple, Dict, TypedDict, Optional, TypeVar
 
 from py_dot.core.date import Period, DateParts
 
-
 class SummaryTimeUnit:
     year = 'year'
     month = 'month'
@@ -37,54 +36,67 @@ class SummaryTimeUnit:
         self.default = default
 
 
-def get_summary_unit(
-        period: Period,
-        unit: Union[SummaryTimeUnit, Type[SummaryTimeUnit]] = SummaryTimeUnit,
-        year_days: int = 365,
-        month_days: int = 30,
-        year_from: int = 3,
-        month_from: int = 6,
-        date_from: int = 3,
-        hour_from: int = 28,
-        minute_from: int = 3599
-) -> Tuple[any, int, int]:
-    duration_time = period.duration_time
+class SummaryCondition:
+    def __init__(
+            self,
+            period: Period,
+            unit: Union[SummaryTimeUnit, Type[SummaryTimeUnit]] = SummaryTimeUnit,
+            year_days: int = 365,
+            month_days: int = 30,
+            year_from: int = 3,
+            month_from: int = 6,
+            date_from: int = 7,
+            hour_from: int = 28,
+            minute_from: int = 3599
+    ):
+        duration_time = period.duration_time
 
-    begin = DataSummaryTimeDigits(period.begin)
-    end = DataSummaryTimeDigits(period.end)
+        begin = DataSummaryTimeDigits(period.begin)
+        end = DataSummaryTimeDigits(period.end)
 
-    days = ceil(duration_time / 86400)
+        days = ceil(duration_time / 86400)
 
-    if unit.year is not None:
-        if days >= year_days * year_from:
-            return unit.year, begin.y, end.y
+        if unit.year is not None:
+            if days >= year_days * year_from:
+                self.model = unit.year
+                self.begin = begin.y
+                self.end = end.y
+                return
 
-    if unit.month is not None:
-        if days >= month_days * month_from:
-            return unit.month, begin.ym, end.ym
+        if unit.month is not None:
+            if unit.date is None or days >= month_days * month_from:
+                self.model = unit.month
+                self.begin = begin.ym
+                self.end = end.ym
+                return
 
-    if unit.date is not None:
-        if days >= date_from:
-            return unit.date, begin.ymd, end.ymd
+        if unit.date is not None:
+            if unit.hour is None or days >= date_from:
+                self.model = unit.date
+                self.begin = begin.ymd
+                self.end = end.ymd
+                return
 
-    if unit.hour is not None:
-        if days >= hour_from:
-            return unit.hour, begin.ymdh, end.ymdh
+        if unit.hour is not None:
+            if unit.minute is None or days >= hour_from:
+                self.model = unit.hour
+                self.begin = begin.ymdh
+                self.end = end.ymdh
+                return
 
-    if unit.minute is not None:
-        if duration_time >= minute_from:
-            return unit.minute, begin.ymdhi, end.ymdhi
+        if unit.minute is not None:
+            if duration_time >= minute_from:
+                self.model = unit.minute
+                self.begin = begin.ymdhi
+                self.end = end.ymdhi
+                return
 
-    return unit.default, period.begin, period.end
+        self.model = unit.default
+        self.begin = begin.ymdhis
+        self.end = end.ymdhis
 
 
 class DataSummaryTimeDigits:
-    y: int
-    ym: int
-    ymd: int
-    ymdh: int
-    ymdhi: int
-
     def __init__(self, time: datetime = None, parts: DateParts = None):
         if parts is None:
             if time is None:
@@ -92,35 +104,24 @@ class DataSummaryTimeDigits:
 
             parts = DateParts(time)
 
-        y = parts.y
-        m = parts.m
-        d = parts.d
-        h = parts.h
-        i = parts.i
+        y, m, d, h, i, s = parts
 
         ym = y + m
         ymd = ym + d
         ymdh = ymd + h
         ymdhi = ymdh + i
+        ymdhis = ymdhi + s
 
         self.y = int(y)
         self.ym = int(ym)
         self.ymd = int(ymd)
         self.ymdh = int(ymdh)
         self.ymdhi = int(ymdhi)
-
-    def get(self, unit: str):
-        pass
+        self.ymdhis = int(ymdhis)
 
 
 @dataclass
 class DataSummaryTimeStrings:
-    y: str
-    ym: str
-    ymd: str
-    ymdh: str
-    ymdhi: str
-
     def __init__(self, time: datetime = None, parts: DateParts = None):
         if parts is None:
             if time is None:
@@ -128,18 +129,20 @@ class DataSummaryTimeStrings:
 
             parts = DateParts(time)
 
-        y, m, d, h, i = parts
+        y, m, d, h, i, s = parts
 
         ym = y + '-' + m
         ymd = ym + '-' + d
         ymdh = ymd + ' ' + h
         ymdhi = ymdh + ':' + i
+        ymdhis = ymdhi + ':' + s
 
         self.y = y
         self.ym = ym
         self.ymd = ymd
         self.ymdh = ymdh
         self.ymdhi = ymdhi
+        self.ymdhis = ymdhis
 
 
 class DataSummaryTimes:
